@@ -41,7 +41,8 @@ class api:
         with open("access-log.txt", "a") as f:
             f.write("\n")
             f.write(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200'))
-            f.write(request)
+            for key in request.keys():
+                f.write(key + ":" + request[key])
             f.write("\n")
         
         handler = self.find_handler(request)
